package com.google.zxing.common.detector;

import com.google.zxing.NotFoundException;
import com.google.zxing.ResultPoint;
import com.google.zxing.common.BitMatrix;

public final class WhiteRectangleDetector {
    private static final int CORR = 1;
    private static final int INIT_SIZE = 10;
    private final int downInit;
    private final int height;
    private final BitMatrix image;
    private final int leftInit;
    private final int rightInit;
    private final int upInit;
    private final int width;

    public WhiteRectangleDetector(BitMatrix bitMatrix) throws NotFoundException {
        this(bitMatrix, INIT_SIZE, bitMatrix.getWidth() / 2, bitMatrix.getHeight() / 2);
    }

    public WhiteRectangleDetector(BitMatrix bitMatrix, int i, int i2, int i3) throws NotFoundException {
        this.image = bitMatrix;
        this.height = bitMatrix.getHeight();
        this.width = bitMatrix.getWidth();
        int i4 = i / 2;
        this.leftInit = i2 - i4;
        this.rightInit = i2 + i4;
        this.upInit = i3 - i4;
        this.downInit = i3 + i4;
        if (this.upInit < 0 || this.leftInit < 0 || this.downInit >= this.height || this.rightInit >= this.width) {
            throw NotFoundException.getNotFoundInstance();
        }
    }

    public ResultPoint[] detect() throws NotFoundException {
        int i = this.leftInit;
        int i2 = this.rightInit;
        int i3 = this.upInit;
        int i4 = this.downInit;
        boolean z = false;
        int i5 = CORR;
        int i6 = i;
        boolean z2 = false;
        boolean z3 = false;
        boolean z4 = false;
        boolean z5 = false;
        boolean z6 = CORR;
        while (true) {
            if (!z6) {
                break;
            }
            boolean z7 = false;
            boolean z8 = CORR;
            while (true) {
                if ((z8 || !z2) && i2 < this.width) {
                    z8 = containsBlackPoint(i3, i4, i2, false);
                    if (z8) {
                        i2 += CORR;
                        z2 = CORR;
                        z7 = z2;
                    } else if (!z2) {
                        i2 += CORR;
                    }
                }
            }
            if (i2 >= this.width) {
                break;
            }
            boolean z9 = CORR;
            while (true) {
                if ((z9 || !z3) && i4 < this.height) {
                    z9 = containsBlackPoint(i6, i2, i4, true);
                    if (z9) {
                        i4 += CORR;
                        z3 = CORR;
                        z7 = z3;
                    } else if (!z3) {
                        i4 += CORR;
                    }
                }
            }
            if (i4 >= this.height) {
                break;
            }
            boolean z10 = CORR;
            while (true) {
                if ((z10 || !z4) && i6 >= 0) {
                    z10 = containsBlackPoint(i3, i4, i6, false);
                    if (z10) {
                        i6--;
                        z4 = CORR;
                        z7 = z4;
                    } else if (!z4) {
                        i6--;
                    }
                }
            }
            if (i6 < 0) {
                break;
            }
            boolean z11 = CORR;
            while (true) {
                if ((z11 || !z5) && i3 >= 0) {
                    z11 = containsBlackPoint(i6, i2, i3, true);
                    if (z11) {
                        i3--;
                        z5 = CORR;
                        z7 = z5;
                    } else if (!z5) {
                        i3--;
                    }
                }
            }
            if (i3 < 0) {
                break;
            }
            z6 = z7;
        }
        z = CORR;
        if (!z) {
            int i7 = i2 - i6;
            ResultPoint resultPoint = null;
            ResultPoint resultPoint2 = null;
            int i8 = CORR;
            while (resultPoint2 == null && i8 < i7) {
                resultPoint2 = getBlackPointOnSegment((float) i6, (float) (i4 - i8), (float) (i6 + i8), (float) i4);
                i8 += CORR;
            }
            if (resultPoint2 != null) {
                ResultPoint resultPoint3 = null;
                int i9 = CORR;
                while (resultPoint3 == null && i9 < i7) {
                    resultPoint3 = getBlackPointOnSegment((float) i6, (float) (i3 + i9), (float) (i6 + i9), (float) i3);
                    i9 += CORR;
                }
                if (resultPoint3 != null) {
                    ResultPoint resultPoint4 = null;
                    int i10 = CORR;
                    while (resultPoint4 == null && i10 < i7) {
                        resultPoint4 = getBlackPointOnSegment((float) i2, (float) (i3 + i10), (float) (i2 - i10), (float) i3);
                        i10 += CORR;
                    }
                    if (resultPoint4 != null) {
                        while (resultPoint == null && i5 < i7) {
                            resultPoint = getBlackPointOnSegment((float) i2, (float) (i4 - i5), (float) (i2 - i5), (float) i4);
                            i5 += CORR;
                        }
                        if (resultPoint != null) {
                            return centerEdges(resultPoint, resultPoint2, resultPoint4, resultPoint3);
                        }
                        throw NotFoundException.getNotFoundInstance();
                    }
                    throw NotFoundException.getNotFoundInstance();
                }
                throw NotFoundException.getNotFoundInstance();
            }
            throw NotFoundException.getNotFoundInstance();
        }
        throw NotFoundException.getNotFoundInstance();
    }

    private ResultPoint getBlackPointOnSegment(float f, float f2, float f3, float f4) {
        int round = MathUtils.round(MathUtils.distance(f, f2, f3, f4));
        float f5 = (float) round;
        float f6 = (f3 - f) / f5;
        float f7 = (f4 - f2) / f5;
        for (int i = 0; i < round; i += CORR) {
            float f8 = (float) i;
            int round2 = MathUtils.round((f8 * f6) + f);
            int round3 = MathUtils.round((f8 * f7) + f2);
            if (this.image.get(round2, round3)) {
                return new ResultPoint((float) round2, (float) round3);
            }
        }
        return null;
    }

    private ResultPoint[] centerEdges(ResultPoint resultPoint, ResultPoint resultPoint2, ResultPoint resultPoint3, ResultPoint resultPoint4) {
        float x = resultPoint.getX();
        float y = resultPoint.getY();
        float x2 = resultPoint2.getX();
        float y2 = resultPoint2.getY();
        float x3 = resultPoint3.getX();
        float y3 = resultPoint3.getY();
        float x4 = resultPoint4.getX();
        float y4 = resultPoint4.getY();
        if (x < ((float) this.width) / 2.0f) {
            return new ResultPoint[]{new ResultPoint(x4 - 1.0f, y4 + 1.0f), new ResultPoint(x2 + 1.0f, y2 + 1.0f), new ResultPoint(x3 - 1.0f, y3 - 1.0f), new ResultPoint(x + 1.0f, y - 1.0f)};
        }
        return new ResultPoint[]{new ResultPoint(x4 + 1.0f, y4 + 1.0f), new ResultPoint(x2 + 1.0f, y2 - 1.0f), new ResultPoint(x3 - 1.0f, y3 + 1.0f), new ResultPoint(x - 1.0f, y - 1.0f)};
    }

    private boolean containsBlackPoint(int i, int i2, int i3, boolean z) {
        if (z) {
            while (i <= i2) {
                if (this.image.get(i, i3)) {
                    return true;
                }
                i += CORR;
            }
            return false;
        }
        while (i <= i2) {
            if (this.image.get(i3, i)) {
                return true;
            }
            i += CORR;
        }
        return false;
    }
}
