package com.google.zxing.oned;

import com.google.zxing.BarcodeFormat;
import com.google.zxing.DecodeHintType;
import com.google.zxing.FormatException;
import com.google.zxing.NotFoundException;
import com.google.zxing.Result;
import com.google.zxing.ResultPoint;
import com.google.zxing.common.BitArray;
import java.util.Map;

public final class ITFReader extends OneDReader {
    private static final int[] DEFAULT_ALLOWED_LENGTHS = {6, 8, 10, 12, 14};
    private static final int[][] END_PATTERN_REVERSED;
    private static final float MAX_AVG_VARIANCE = 0.38f;
    private static final float MAX_INDIVIDUAL_VARIANCE = 0.5f;
    private static final int N = 1;
    private static final int[][] PATTERNS = {new int[]{N, N, w, w, N}, new int[]{w, N, N, N, w}, new int[]{N, w, N, N, w}, new int[]{w, w, N, N, N}, new int[]{N, N, w, N, w}, new int[]{w, N, w, N, N}, new int[]{N, w, w, N, N}, new int[]{N, N, N, w, w}, new int[]{w, N, N, w, N}, new int[]{N, w, N, w, N}, new int[]{N, N, 3, 3, N}, new int[]{3, N, N, N, 3}, new int[]{N, 3, N, N, 3}, new int[]{3, 3, N, N, N}, new int[]{N, N, 3, N, 3}, new int[]{3, N, 3, N, N}, new int[]{N, 3, 3, N, N}, new int[]{N, N, N, 3, 3}, new int[]{3, N, N, 3, N}, new int[]{N, 3, N, 3, N}};
    private static final int[] START_PATTERN = {N, N, N, N};
    private static final int W = 3;
    private static final int w = 2;
    private int narrowLineWidth = -1;

    static {
        int[][] iArr = new int[w][];
        iArr[0] = new int[]{N, N, w};
        iArr[N] = new int[]{N, N, 3};
        END_PATTERN_REVERSED = iArr;
    }

    @Override // com.google.zxing.oned.OneDReader
    public Result decodeRow(int i, BitArray bitArray, Map<DecodeHintType, ?> map) throws FormatException, NotFoundException {
        boolean z;
        int[] decodeStart = decodeStart(bitArray);
        int[] decodeEnd = decodeEnd(bitArray);
        StringBuilder sb = new StringBuilder(20);
        decodeMiddle(bitArray, decodeStart[N], decodeEnd[0], sb);
        String sb2 = sb.toString();
        int[] iArr = map != null ? (int[]) map.get(DecodeHintType.ALLOWED_LENGTHS) : null;
        if (iArr == null) {
            iArr = DEFAULT_ALLOWED_LENGTHS;
        }
        int length = sb2.length();
        int length2 = iArr.length;
        int i2 = 0;
        int i3 = 0;
        while (true) {
            if (i2 >= length2) {
                z = false;
                break;
            }
            int i4 = iArr[i2];
            if (length == i4) {
                z = N;
                break;
            }
            if (i4 > i3) {
                i3 = i4;
            }
            i2 += N;
        }
        if (!z && length > i3) {
            z = N;
        }
        if (z) {
            ResultPoint[] resultPointArr = new ResultPoint[w];
            float f = (float) i;
            resultPointArr[0] = new ResultPoint((float) decodeStart[N], f);
            resultPointArr[N] = new ResultPoint((float) decodeEnd[0], f);
            return new Result(sb2, null, resultPointArr, BarcodeFormat.ITF);
        }
        throw FormatException.getFormatInstance();
    }

    private static void decodeMiddle(BitArray bitArray, int i, int i2, StringBuilder sb) throws NotFoundException {
        int[] iArr = new int[10];
        int[] iArr2 = new int[5];
        int[] iArr3 = new int[5];
        while (i < i2) {
            recordPattern(bitArray, i, iArr);
            for (int i3 = 0; i3 < 5; i3 += N) {
                int i4 = i3 * w;
                iArr2[i3] = iArr[i4];
                iArr3[i3] = iArr[i4 + N];
            }
            sb.append((char) (decodeDigit(iArr2) + 48));
            sb.append((char) (decodeDigit(iArr3) + 48));
            int length = iArr.length;
            for (int i5 = 0; i5 < length; i5 += N) {
                i += iArr[i5];
            }
        }
    }

    private int[] decodeStart(BitArray bitArray) throws NotFoundException {
        int[] findGuardPattern = findGuardPattern(bitArray, skipWhiteSpace(bitArray), START_PATTERN);
        this.narrowLineWidth = (findGuardPattern[N] - findGuardPattern[0]) / 4;
        validateQuietZone(bitArray, findGuardPattern[0]);
        return findGuardPattern;
    }

    private void validateQuietZone(BitArray bitArray, int i) throws NotFoundException {
        int i2 = this.narrowLineWidth * 10;
        if (i2 >= i) {
            i2 = i;
        }
        int i3 = i - 1;
        while (i2 > 0 && i3 >= 0 && !bitArray.get(i3)) {
            i2--;
            i3--;
        }
        if (i2 != 0) {
            throw NotFoundException.getNotFoundInstance();
        }
    }

    private static int skipWhiteSpace(BitArray bitArray) throws NotFoundException {
        int size = bitArray.getSize();
        int nextSet = bitArray.getNextSet(0);
        if (nextSet != size) {
            return nextSet;
        }
        throw NotFoundException.getNotFoundInstance();
    }

    private int[] decodeEnd(BitArray bitArray) throws NotFoundException {
        int[] iArr;
        int i;
        bitArray.reverse();
        try {
            try {
                iArr = findGuardPattern(bitArray, skipWhiteSpace(bitArray), END_PATTERN_REVERSED[0]);
            } catch (NotFoundException unused) {
                iArr = findGuardPattern(bitArray, i, END_PATTERN_REVERSED[N]);
            }
            validateQuietZone(bitArray, iArr[0]);
            int i2 = iArr[0];
            iArr[0] = bitArray.getSize() - iArr[N];
            iArr[N] = bitArray.getSize() - i2;
            return iArr;
        } finally {
            bitArray.reverse();
        }
    }

    private static int[] findGuardPattern(BitArray bitArray, int i, int[] iArr) throws NotFoundException {
        int length = iArr.length;
        int[] iArr2 = new int[length];
        int size = bitArray.getSize();
        int i2 = i;
        boolean z = false;
        int i3 = 0;
        while (i < size) {
            if (bitArray.get(i) != z) {
                iArr2[i3] = iArr2[i3] + N;
            } else {
                if (i3 != length - 1) {
                    i3 += N;
                } else if (patternMatchVariance(iArr2, iArr, MAX_INDIVIDUAL_VARIANCE) < MAX_AVG_VARIANCE) {
                    int[] iArr3 = new int[w];
                    iArr3[0] = i2;
                    iArr3[N] = i;
                    return iArr3;
                } else {
                    i2 += iArr2[0] + iArr2[N];
                    int i4 = i3 - 1;
                    System.arraycopy(iArr2, w, iArr2, 0, i4);
                    iArr2[i4] = 0;
                    iArr2[i3] = 0;
                    i3--;
                }
                iArr2[i3] = N;
                z = !z;
            }
            i += N;
        }
        throw NotFoundException.getNotFoundInstance();
    }

    private static int decodeDigit(int[] iArr) throws NotFoundException {
        int length = PATTERNS.length;
        float f = 0.38f;
        int i = -1;
        for (int i2 = 0; i2 < length; i2 += N) {
            float patternMatchVariance = patternMatchVariance(iArr, PATTERNS[i2], MAX_INDIVIDUAL_VARIANCE);
            if (patternMatchVariance < f) {
                i = i2;
                f = patternMatchVariance;
            } else if (patternMatchVariance == f) {
                i = -1;
            }
        }
        if (i >= 0) {
            return i % 10;
        }
        throw NotFoundException.getNotFoundInstance();
    }
}
