package com.google.zxing.oned;

import com.google.zxing.BarcodeFormat;
import com.google.zxing.EncodeHintType;
import com.google.zxing.WriterException;
import com.google.zxing.common.BitMatrix;
import java.util.Map;

public final class ITFWriter extends OneDimensionalCodeWriter {
    private static final int[] END_PATTERN = {3, N, N};
    private static final int N = 1;
    private static final int[][] PATTERNS = {new int[]{N, N, 3, 3, N}, new int[]{3, N, N, N, 3}, new int[]{N, 3, N, N, 3}, new int[]{3, 3, N, N, N}, new int[]{N, N, 3, N, 3}, new int[]{3, N, 3, N, N}, new int[]{N, 3, 3, N, N}, new int[]{N, N, N, 3, 3}, new int[]{3, N, N, 3, N}, new int[]{N, 3, N, 3, N}};
    private static final int[] START_PATTERN = {N, N, N, N};
    private static final int W = 3;

    @Override // com.google.zxing.oned.OneDimensionalCodeWriter, com.google.zxing.Writer
    public BitMatrix encode(String str, BarcodeFormat barcodeFormat, int i, int i2, Map<EncodeHintType, ?> map) throws WriterException {
        if (barcodeFormat == BarcodeFormat.ITF) {
            return super.encode(str, barcodeFormat, i, i2, map);
        }
        throw new IllegalArgumentException("Can only encode ITF, but got " + barcodeFormat);
    }

    @Override // com.google.zxing.oned.OneDimensionalCodeWriter
    public boolean[] encode(String str) {
        int length = str.length();
        if (length % 2 != 0) {
            throw new IllegalArgumentException("The length of the input should be even");
        } else if (length <= 80) {
            checkNumeric(str);
            boolean[] zArr = new boolean[((length * 9) + 9)];
            int appendPattern = appendPattern(zArr, 0, START_PATTERN, true);
            for (int i = 0; i < length; i += 2) {
                int digit = Character.digit(str.charAt(i), 10);
                int digit2 = Character.digit(str.charAt(i + N), 10);
                int[] iArr = new int[10];
                for (int i2 = 0; i2 < 5; i2 += N) {
                    int i3 = i2 * 2;
                    int[][] iArr2 = PATTERNS;
                    iArr[i3] = iArr2[digit][i2];
                    iArr[i3 + N] = iArr2[digit2][i2];
                }
                appendPattern += appendPattern(zArr, appendPattern, iArr, true);
            }
            appendPattern(zArr, appendPattern, END_PATTERN, true);
            return zArr;
        } else {
            throw new IllegalArgumentException("Requested contents should be less than 80 digits long, but got " + length);
        }
    }
}
