package com.google.zxing.oned.rss.expanded;

import com.google.zxing.BarcodeFormat;
import com.google.zxing.DecodeHintType;
import com.google.zxing.FormatException;
import com.google.zxing.NotFoundException;
import com.google.zxing.Result;
import com.google.zxing.ResultPoint;
import com.google.zxing.common.BitArray;
import com.google.zxing.common.detector.MathUtils;
import com.google.zxing.oned.rss.AbstractRSSReader;
import com.google.zxing.oned.rss.DataCharacter;
import com.google.zxing.oned.rss.FinderPattern;
import com.google.zxing.oned.rss.RSSUtils;
import com.google.zxing.oned.rss.expanded.decoders.AbstractExpandedDecoder;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

public final class RSSExpandedReader extends AbstractRSSReader {
    private static final int[] EVEN_TOTAL_SUBSET = {FINDER_PAT_E, 20, 52, 104, 204};
    private static final int[][] FINDER_PATTERNS = {new int[]{FINDER_PAT_B, 8, FINDER_PAT_E, FINDER_PAT_B}, new int[]{3, 6, FINDER_PAT_E, FINDER_PAT_B}, new int[]{3, FINDER_PAT_E, 6, FINDER_PAT_B}, new int[]{3, FINDER_PAT_C, 8, FINDER_PAT_B}, new int[]{FINDER_PAT_C, 6, FINDER_PAT_F, FINDER_PAT_B}, new int[]{FINDER_PAT_C, FINDER_PAT_C, 9, FINDER_PAT_B}};
    private static final int[][] FINDER_PATTERN_SEQUENCES = {new int[]{0, 0}, new int[]{0, FINDER_PAT_B, FINDER_PAT_B}, new int[]{0, FINDER_PAT_C, FINDER_PAT_B, 3}, new int[]{0, FINDER_PAT_E, FINDER_PAT_B, 3, FINDER_PAT_C}, new int[]{0, FINDER_PAT_E, FINDER_PAT_B, 3, 3, FINDER_PAT_F}, new int[]{0, FINDER_PAT_E, FINDER_PAT_B, 3, FINDER_PAT_E, FINDER_PAT_F, FINDER_PAT_F}, new int[]{0, 0, FINDER_PAT_B, FINDER_PAT_B, FINDER_PAT_C, FINDER_PAT_C, 3, 3}, new int[]{0, 0, FINDER_PAT_B, FINDER_PAT_B, FINDER_PAT_C, FINDER_PAT_C, 3, FINDER_PAT_E, FINDER_PAT_E}, new int[]{0, 0, FINDER_PAT_B, FINDER_PAT_B, FINDER_PAT_C, FINDER_PAT_C, 3, FINDER_PAT_E, FINDER_PAT_F, FINDER_PAT_F}, new int[]{0, 0, FINDER_PAT_B, FINDER_PAT_B, FINDER_PAT_C, 3, 3, FINDER_PAT_E, FINDER_PAT_E, FINDER_PAT_F, FINDER_PAT_F}};
    private static final int FINDER_PAT_A = 0;
    private static final int FINDER_PAT_B = 1;
    private static final int FINDER_PAT_C = 2;
    private static final int FINDER_PAT_D = 3;
    private static final int FINDER_PAT_E = 4;
    private static final int FINDER_PAT_F = 5;
    private static final int[] GSUM = {0, 348, 1388, 2948, 3988};
    private static final int MAX_PAIRS = 11;
    private static final int[] SYMBOL_WIDEST = {7, FINDER_PAT_F, FINDER_PAT_E, 3, FINDER_PAT_B};
    private static final int[][] WEIGHTS = {new int[]{FINDER_PAT_B, 3, 9, 27, 81, 32, 96, 77}, new int[]{20, 60, 180, 118, 143, 7, 21, 63}, new int[]{189, 145, 13, 39, 117, 140, 209, 205}, new int[]{193, 157, 49, 147, 19, 57, 171, 91}, new int[]{62, 186, 136, 197, 169, 85, 44, 132}, new int[]{185, 133, 188, 142, FINDER_PAT_E, 12, 36, 108}, new int[]{113, 128, 173, 97, 80, 29, 87, 50}, new int[]{150, 28, 84, 41, 123, 158, 52, 156}, new int[]{46, 138, 203, 187, 139, 206, 196, 166}, new int[]{76, 17, 51, 153, 37, 111, 122, 155}, new int[]{43, 129, 176, 106, 107, 110, 119, 146}, new int[]{16, 48, 144, 10, 30, 90, 59, 177}, new int[]{109, 116, 137, 200, 178, 112, 125, 164}, new int[]{70, 210, 208, 202, 184, 130, 179, 115}, new int[]{134, 191, 151, 31, 93, 68, 204, 190}, new int[]{148, 22, 66, 198, 172, 94, 71, FINDER_PAT_C}, new int[]{6, 18, 54, 162, 64, 192, 154, 40}, new int[]{120, 149, 25, 75, 14, 42, 126, 167}, new int[]{79, 26, 78, 23, 69, 207, 199, 175}, new int[]{103, 98, 83, 38, 114, 131, 182, 124}, new int[]{161, 61, 183, 127, 170, 88, 53, 159}, new int[]{55, 165, 73, 8, 24, 72, FINDER_PAT_F, 15}, new int[]{45, 135, 194, 160, 58, 174, 100, 89}};
    private final List<ExpandedPair> pairs = new ArrayList((int) MAX_PAIRS);
    private final List<ExpandedRow> rows = new ArrayList();
    private final int[] startEnd = new int[FINDER_PAT_C];
    private boolean startFromEven;

    @Override // com.google.zxing.oned.OneDReader
    public Result decodeRow(int i, BitArray bitArray, Map<DecodeHintType, ?> map) throws NotFoundException, FormatException {
        this.pairs.clear();
        this.startFromEven = false;
        try {
            return constructResult(decodeRow2pairs(i, bitArray));
        } catch (NotFoundException unused) {
            this.pairs.clear();
            this.startFromEven = true;
            return constructResult(decodeRow2pairs(i, bitArray));
        }
    }

    @Override // com.google.zxing.Reader, com.google.zxing.oned.OneDReader
    public void reset() {
        this.pairs.clear();
        this.rows.clear();
    }

    /* access modifiers changed from: package-private */
    public List<ExpandedPair> decodeRow2pairs(int i, BitArray bitArray) throws NotFoundException {
        boolean z = false;
        while (!z) {
            try {
                this.pairs.add(retrieveNextPair(bitArray, this.pairs, i));
            } catch (NotFoundException e) {
                if (!this.pairs.isEmpty()) {
                    z = FINDER_PAT_B;
                } else {
                    throw e;
                }
            }
        }
        if (checkChecksum()) {
            return this.pairs;
        }
        boolean isEmpty = this.rows.isEmpty() ^ FINDER_PAT_B;
        storeRow(i, false);
        if (isEmpty) {
            List<ExpandedPair> checkRows = checkRows(false);
            if (checkRows != null) {
                return checkRows;
            }
            List<ExpandedPair> checkRows2 = checkRows(true);
            if (checkRows2 != null) {
                return checkRows2;
            }
        }
        throw NotFoundException.getNotFoundInstance();
    }

    private List<ExpandedPair> checkRows(boolean z) {
        List<ExpandedPair> list = null;
        if (this.rows.size() > 25) {
            this.rows.clear();
            return null;
        }
        this.pairs.clear();
        if (z) {
            Collections.reverse(this.rows);
        }
        try {
            list = checkRows(new ArrayList(), 0);
        } catch (NotFoundException unused) {
        }
        if (z) {
            Collections.reverse(this.rows);
        }
        return list;
    }

    private List<ExpandedPair> checkRows(List<ExpandedRow> list, int i) throws NotFoundException {
        while (i < this.rows.size()) {
            ExpandedRow expandedRow = this.rows.get(i);
            this.pairs.clear();
            for (ExpandedRow expandedRow2 : list) {
                this.pairs.addAll(expandedRow2.getPairs());
            }
            this.pairs.addAll(expandedRow.getPairs());
            if (!isValidSequence(this.pairs)) {
                i += FINDER_PAT_B;
            } else if (checkChecksum()) {
                return this.pairs;
            } else {
                ArrayList arrayList = new ArrayList(list);
                arrayList.add(expandedRow);
                try {
                    return checkRows(arrayList, i + FINDER_PAT_B);
                } catch (NotFoundException unused) {
                    continue;
                }
            }
        }
        throw NotFoundException.getNotFoundInstance();
    }

    private static boolean isValidSequence(List<ExpandedPair> list) {
        boolean z;
        int[][] iArr = FINDER_PATTERN_SEQUENCES;
        int length = iArr.length;
        for (int i = 0; i < length; i += FINDER_PAT_B) {
            int[] iArr2 = iArr[i];
            if (list.size() <= iArr2.length) {
                int i2 = 0;
                while (true) {
                    if (i2 >= list.size()) {
                        z = FINDER_PAT_B;
                        break;
                    } else if (list.get(i2).getFinderPattern().getValue() != iArr2[i2]) {
                        z = false;
                        break;
                    } else {
                        i2 += FINDER_PAT_B;
                    }
                }
                if (z) {
                    return true;
                }
            }
        }
        return false;
    }

    private void storeRow(int i, boolean z) {
        boolean z2 = false;
        int i2 = 0;
        boolean z3 = false;
        while (true) {
            if (i2 >= this.rows.size()) {
                break;
            }
            ExpandedRow expandedRow = this.rows.get(i2);
            if (expandedRow.getRowNumber() > i) {
                z2 = expandedRow.isEquivalent(this.pairs);
                break;
            } else {
                z3 = expandedRow.isEquivalent(this.pairs);
                i2 += FINDER_PAT_B;
            }
        }
        if (!z2 && !z3 && !isPartialRow(this.pairs, this.rows)) {
            this.rows.add(i2, new ExpandedRow(this.pairs, i, z));
            removePartialRows(this.pairs, this.rows);
        }
    }

    private static void removePartialRows(Collection<ExpandedPair> collection, Collection<ExpandedRow> collection2) {
        Iterator<ExpandedRow> it = collection2.iterator();
        while (it.hasNext()) {
            ExpandedRow next = it.next();
            if (next.getPairs().size() != collection.size()) {
                boolean z = true;
                Iterator<ExpandedPair> it2 = next.getPairs().iterator();
                while (true) {
                    if (it2.hasNext()) {
                        if (!collection.contains(it2.next())) {
                            z = false;
                            break;
                        }
                    } else {
                        break;
                    }
                }
                if (z) {
                    it.remove();
                }
            }
        }
    }

    private static boolean isPartialRow(Iterable<ExpandedPair> iterable, Iterable<ExpandedRow> iterable2) {
        boolean z;
        boolean z2;
        Iterator<ExpandedRow> it = iterable2.iterator();
        do {
            z = false;
            if (it.hasNext()) {
                ExpandedRow next = it.next();
                Iterator<ExpandedPair> it2 = iterable.iterator();
                while (true) {
                    if (!it2.hasNext()) {
                        z = FINDER_PAT_B;
                        continue;
                        break;
                    }
                    ExpandedPair next2 = it2.next();
                    Iterator<ExpandedPair> it3 = next.getPairs().iterator();
                    while (true) {
                        if (it3.hasNext()) {
                            if (next2.equals(it3.next())) {
                                z2 = FINDER_PAT_B;
                                continue;
                                break;
                            }
                        } else {
                            z2 = false;
                            continue;
                            break;
                        }
                    }
                    if (!z2) {
                        continue;
                        break;
                    }
                }
            } else {
                return false;
            }
        } while (!z);
        return true;
    }

    /* access modifiers changed from: package-private */
    public List<ExpandedRow> getRows() {
        return this.rows;
    }

    static Result constructResult(List<ExpandedPair> list) throws NotFoundException, FormatException {
        String parseInformation = AbstractExpandedDecoder.createDecoder(BitArrayBuilder.buildBitArray(list)).parseInformation();
        ResultPoint[] resultPoints = list.get(0).getFinderPattern().getResultPoints();
        ResultPoint[] resultPoints2 = list.get(list.size() - FINDER_PAT_B).getFinderPattern().getResultPoints();
        ResultPoint[] resultPointArr = new ResultPoint[FINDER_PAT_E];
        resultPointArr[0] = resultPoints[0];
        resultPointArr[FINDER_PAT_B] = resultPoints[FINDER_PAT_B];
        resultPointArr[FINDER_PAT_C] = resultPoints2[0];
        resultPointArr[3] = resultPoints2[FINDER_PAT_B];
        return new Result(parseInformation, null, resultPointArr, BarcodeFormat.RSS_EXPANDED);
    }

    private boolean checkChecksum() {
        ExpandedPair expandedPair = this.pairs.get(0);
        DataCharacter leftChar = expandedPair.getLeftChar();
        DataCharacter rightChar = expandedPair.getRightChar();
        if (rightChar == null) {
            return false;
        }
        int checksumPortion = rightChar.getChecksumPortion();
        int i = FINDER_PAT_C;
        int i2 = checksumPortion;
        for (int i3 = FINDER_PAT_B; i3 < this.pairs.size(); i3 += FINDER_PAT_B) {
            ExpandedPair expandedPair2 = this.pairs.get(i3);
            i2 += expandedPair2.getLeftChar().getChecksumPortion();
            i += FINDER_PAT_B;
            DataCharacter rightChar2 = expandedPair2.getRightChar();
            if (rightChar2 != null) {
                i2 += rightChar2.getChecksumPortion();
                i += FINDER_PAT_B;
            }
        }
        if (((i - 4) * 211) + (i2 % 211) == leftChar.getValue()) {
            return true;
        }
        return false;
    }

    private static int getNextSecondBar(BitArray bitArray, int i) {
        if (bitArray.get(i)) {
            return bitArray.getNextSet(bitArray.getNextUnset(i));
        }
        return bitArray.getNextUnset(bitArray.getNextSet(i));
    }

    /* access modifiers changed from: package-private */
    public ExpandedPair retrieveNextPair(BitArray bitArray, List<ExpandedPair> list, int i) throws NotFoundException {
        FinderPattern parseFoundFinderPattern;
        DataCharacter dataCharacter;
        boolean z = list.size() % FINDER_PAT_C == 0 ? FINDER_PAT_B : false;
        if (this.startFromEven) {
            z = !z;
        }
        int i2 = -1;
        boolean z2 = FINDER_PAT_B;
        do {
            findNextPair(bitArray, list, i2);
            parseFoundFinderPattern = parseFoundFinderPattern(bitArray, i, z);
            if (parseFoundFinderPattern == null) {
                i2 = getNextSecondBar(bitArray, this.startEnd[0]);
                continue;
            } else {
                z2 = false;
                continue;
            }
        } while (z2);
        DataCharacter decodeDataCharacter = decodeDataCharacter(bitArray, parseFoundFinderPattern, z, true);
        if (list.isEmpty() || !list.get(list.size() - FINDER_PAT_B).mustBeLast()) {
            try {
                dataCharacter = decodeDataCharacter(bitArray, parseFoundFinderPattern, z, false);
            } catch (NotFoundException unused) {
                dataCharacter = null;
            }
            return new ExpandedPair(decodeDataCharacter, dataCharacter, parseFoundFinderPattern);
        }
        throw NotFoundException.getNotFoundInstance();
    }

    private void findNextPair(BitArray bitArray, List<ExpandedPair> list, int i) throws NotFoundException {
        int[] decodeFinderCounters = getDecodeFinderCounters();
        decodeFinderCounters[0] = 0;
        decodeFinderCounters[FINDER_PAT_B] = 0;
        decodeFinderCounters[FINDER_PAT_C] = 0;
        decodeFinderCounters[3] = 0;
        int size = bitArray.getSize();
        if (i < 0) {
            if (list.isEmpty()) {
                i = 0;
            } else {
                i = list.get(list.size() - FINDER_PAT_B).getFinderPattern().getStartEnd()[FINDER_PAT_B];
            }
        }
        boolean z = list.size() % FINDER_PAT_C != 0 ? FINDER_PAT_B : false;
        if (this.startFromEven) {
            z = !z;
        }
        boolean z2 = false;
        while (i < size) {
            z2 = bitArray.get(i) ^ FINDER_PAT_B;
            if (!z2) {
                break;
            }
            i += FINDER_PAT_B;
        }
        int i2 = i;
        int i3 = 0;
        while (i < size) {
            if (bitArray.get(i) != z2) {
                decodeFinderCounters[i3] = decodeFinderCounters[i3] + FINDER_PAT_B;
            } else {
                if (i3 == 3) {
                    if (z) {
                        reverseCounters(decodeFinderCounters);
                    }
                    if (isFinderPattern(decodeFinderCounters)) {
                        int[] iArr = this.startEnd;
                        iArr[0] = i2;
                        iArr[FINDER_PAT_B] = i;
                        return;
                    }
                    if (z) {
                        reverseCounters(decodeFinderCounters);
                    }
                    i2 += decodeFinderCounters[0] + decodeFinderCounters[FINDER_PAT_B];
                    decodeFinderCounters[0] = decodeFinderCounters[FINDER_PAT_C];
                    decodeFinderCounters[FINDER_PAT_B] = decodeFinderCounters[3];
                    decodeFinderCounters[FINDER_PAT_C] = 0;
                    decodeFinderCounters[3] = 0;
                    i3--;
                } else {
                    i3 += FINDER_PAT_B;
                }
                decodeFinderCounters[i3] = FINDER_PAT_B;
                z2 = !z2;
            }
            i += FINDER_PAT_B;
        }
        throw NotFoundException.getNotFoundInstance();
    }

    private static void reverseCounters(int[] iArr) {
        int length = iArr.length;
        for (int i = 0; i < length / FINDER_PAT_C; i += FINDER_PAT_B) {
            int i2 = iArr[i];
            int i3 = (length - i) - 1;
            iArr[i] = iArr[i3];
            iArr[i3] = i2;
        }
    }

    private FinderPattern parseFoundFinderPattern(BitArray bitArray, int i, boolean z) {
        int i2;
        int i3;
        int i4;
        if (z) {
            int i5 = this.startEnd[0] - FINDER_PAT_B;
            while (i5 >= 0 && !bitArray.get(i5)) {
                i5--;
            }
            int i6 = i5 + FINDER_PAT_B;
            int[] iArr = this.startEnd;
            i3 = iArr[FINDER_PAT_B];
            i4 = i6;
            i2 = iArr[0] - i6;
        } else {
            int[] iArr2 = this.startEnd;
            int i7 = iArr2[0];
            int nextUnset = bitArray.getNextUnset(iArr2[FINDER_PAT_B] + FINDER_PAT_B);
            i2 = nextUnset - this.startEnd[FINDER_PAT_B];
            i3 = nextUnset;
            i4 = i7;
        }
        int[] decodeFinderCounters = getDecodeFinderCounters();
        System.arraycopy(decodeFinderCounters, 0, decodeFinderCounters, FINDER_PAT_B, decodeFinderCounters.length - FINDER_PAT_B);
        decodeFinderCounters[0] = i2;
        try {
            int parseFinderValue = parseFinderValue(decodeFinderCounters, FINDER_PATTERNS);
            int[] iArr3 = new int[FINDER_PAT_C];
            iArr3[0] = i4;
            iArr3[FINDER_PAT_B] = i3;
            return new FinderPattern(parseFinderValue, iArr3, i4, i3, i);
        } catch (NotFoundException unused) {
            return null;
        }
    }

    /* access modifiers changed from: package-private */
    public DataCharacter decodeDataCharacter(BitArray bitArray, FinderPattern finderPattern, boolean z, boolean z2) throws NotFoundException {
        int[] dataCharacterCounters = getDataCharacterCounters();
        for (int i = 0; i < dataCharacterCounters.length; i += FINDER_PAT_B) {
            dataCharacterCounters[i] = 0;
        }
        if (z2) {
            recordPatternInReverse(bitArray, finderPattern.getStartEnd()[0], dataCharacterCounters);
        } else {
            recordPattern(bitArray, finderPattern.getStartEnd()[FINDER_PAT_B], dataCharacterCounters);
            int i2 = 0;
            for (int length = dataCharacterCounters.length - FINDER_PAT_B; i2 < length; length--) {
                int i3 = dataCharacterCounters[i2];
                dataCharacterCounters[i2] = dataCharacterCounters[length];
                dataCharacterCounters[length] = i3;
                i2 += FINDER_PAT_B;
            }
        }
        float sum = ((float) MathUtils.sum(dataCharacterCounters)) / ((float) 17);
        float f = ((float) (finderPattern.getStartEnd()[FINDER_PAT_B] - finderPattern.getStartEnd()[0])) / 15.0f;
        if (Math.abs(sum - f) / f <= 0.3f) {
            int[] oddCounts = getOddCounts();
            int[] evenCounts = getEvenCounts();
            float[] oddRoundingErrors = getOddRoundingErrors();
            float[] evenRoundingErrors = getEvenRoundingErrors();
            for (int i4 = 0; i4 < dataCharacterCounters.length; i4 += FINDER_PAT_B) {
                float f2 = (((float) dataCharacterCounters[i4]) * 1.0f) / sum;
                int i5 = (int) (0.5f + f2);
                if (i5 < FINDER_PAT_B) {
                    if (f2 >= 0.3f) {
                        i5 = FINDER_PAT_B;
                    } else {
                        throw NotFoundException.getNotFoundInstance();
                    }
                } else if (i5 > 8) {
                    if (f2 <= 8.7f) {
                        i5 = 8;
                    } else {
                        throw NotFoundException.getNotFoundInstance();
                    }
                }
                int i6 = i4 / FINDER_PAT_C;
                if ((i4 & FINDER_PAT_B) == 0) {
                    oddCounts[i6] = i5;
                    oddRoundingErrors[i6] = f2 - ((float) i5);
                } else {
                    evenCounts[i6] = i5;
                    evenRoundingErrors[i6] = f2 - ((float) i5);
                }
            }
            adjustOddEvenCounts(17);
            int value = (((finderPattern.getValue() * FINDER_PAT_E) + (z ? 0 : FINDER_PAT_C)) + (!z2 ? 1 : 0)) - FINDER_PAT_B;
            int i7 = 0;
            int i8 = 0;
            for (int length2 = oddCounts.length - FINDER_PAT_B; length2 >= 0; length2--) {
                if (isNotA1left(finderPattern, z, z2)) {
                    i7 += oddCounts[length2] * WEIGHTS[value][length2 * FINDER_PAT_C];
                }
                i8 += oddCounts[length2];
            }
            int i9 = 0;
            for (int length3 = evenCounts.length - FINDER_PAT_B; length3 >= 0; length3--) {
                if (isNotA1left(finderPattern, z, z2)) {
                    i9 += evenCounts[length3] * WEIGHTS[value][(length3 * FINDER_PAT_C) + FINDER_PAT_B];
                }
            }
            int i10 = i7 + i9;
            if ((i8 & FINDER_PAT_B) != 0 || i8 > 13 || i8 < FINDER_PAT_E) {
                throw NotFoundException.getNotFoundInstance();
            }
            int i11 = (13 - i8) / FINDER_PAT_C;
            int i12 = SYMBOL_WIDEST[i11];
            return new DataCharacter((RSSUtils.getRSSvalue(oddCounts, i12, true) * EVEN_TOTAL_SUBSET[i11]) + RSSUtils.getRSSvalue(evenCounts, 9 - i12, false) + GSUM[i11], i10);
        }
        throw NotFoundException.getNotFoundInstance();
    }

    private static boolean isNotA1left(FinderPattern finderPattern, boolean z, boolean z2) {
        return finderPattern.getValue() != 0 || !z || !z2;
    }

    private void adjustOddEvenCounts(int i) throws NotFoundException {
        boolean z;
        boolean z2;
        boolean z3;
        boolean z4;
        int sum = MathUtils.sum(getOddCounts());
        int sum2 = MathUtils.sum(getEvenCounts());
        boolean z5 = false;
        if (sum > 13) {
            z = false;
            z2 = FINDER_PAT_B;
        } else {
            z2 = false;
            z = sum < FINDER_PAT_E ? FINDER_PAT_B : false;
        }
        if (sum2 > 13) {
            z4 = false;
            z3 = FINDER_PAT_B;
        } else if (sum2 < FINDER_PAT_E) {
            z3 = false;
            z4 = FINDER_PAT_B;
        } else {
            z4 = false;
            z3 = false;
        }
        int i2 = (sum + sum2) - i;
        boolean z6 = (sum & FINDER_PAT_B) == FINDER_PAT_B ? FINDER_PAT_B : false;
        if ((sum2 & FINDER_PAT_B) == 0) {
            z5 = FINDER_PAT_B;
        }
        if (i2 != -1) {
            if (i2 != 0) {
                if (i2 != FINDER_PAT_B) {
                    throw NotFoundException.getNotFoundInstance();
                } else if (z6) {
                    if (!z5) {
                        z2 = FINDER_PAT_B;
                    } else {
                        throw NotFoundException.getNotFoundInstance();
                    }
                } else if (z5) {
                    z3 = FINDER_PAT_B;
                } else {
                    throw NotFoundException.getNotFoundInstance();
                }
            } else if (z6) {
                if (!z5) {
                    throw NotFoundException.getNotFoundInstance();
                } else if (sum < sum2) {
                    z3 = FINDER_PAT_B;
                    z = z3;
                } else {
                    z4 = FINDER_PAT_B;
                    z2 = z4;
                }
            } else if (z5) {
                throw NotFoundException.getNotFoundInstance();
            }
        } else if (z6) {
            if (!z5) {
                z = FINDER_PAT_B;
            } else {
                throw NotFoundException.getNotFoundInstance();
            }
        } else if (z5) {
            z4 = FINDER_PAT_B;
        } else {
            throw NotFoundException.getNotFoundInstance();
        }
        if (z) {
            if (!z2) {
                increment(getOddCounts(), getOddRoundingErrors());
            } else {
                throw NotFoundException.getNotFoundInstance();
            }
        }
        if (z2) {
            decrement(getOddCounts(), getOddRoundingErrors());
        }
        if (z4) {
            if (!z3) {
                increment(getEvenCounts(), getOddRoundingErrors());
            } else {
                throw NotFoundException.getNotFoundInstance();
            }
        }
        if (z3) {
            decrement(getEvenCounts(), getEvenRoundingErrors());
        }
    }
}
