package org.pix.healthcode;

import android.content.SharedPreferences;
import android.os.Bundle;
import android.preference.EditTextPreference;
import android.preference.ListPreference;
import android.preference.Preference;
import android.preference.PreferenceActivity;
import android.preference.PreferenceCategory;
import android.util.Log;

public class ConfigActivity extends PreferenceActivity implements SharedPreferences.OnSharedPreferenceChangeListener {
    private static final String TAG = "ConfigActivity";
    private PrefsConfig cfg;
    private SharedPreferences sharedPrefs;
    private int userIndex;

    /* access modifiers changed from: protected */
    public void onCreate(Bundle bundle) {
        super.onCreate(bundle);
        this.cfg = new PrefsConfig(this);
        this.sharedPrefs = getPreferenceManager().getSharedPreferences();
        this.userIndex = getIntent().getIntExtra("INDEX", 0);
        addPreferencesFromResource(ResourceUtil.getId(this, "R.xml.config" + this.userIndex));
        setTitle(String.format(getString(R.string.menu_edit_user), Integer.valueOf(this.userIndex + 1)));
    }

    /* access modifiers changed from: protected */
    public void onResume() {
        super.onResume();
        Log.d(TAG, "onResume(userIndex=" + this.userIndex);
        ((ListPreference) findPreference("KEY_PROVINCE" + this.userIndex)).setSummary(this.cfg.getProvince(this.userIndex));
        ListPreference listPreference = (ListPreference) findPreference("KEY_CITY" + this.userIndex);
        listPreference.setSummary(this.cfg.getCity(this.userIndex));
        int citiesResId = this.cfg.getCitiesResId(this.userIndex);
        listPreference.setEntries(citiesResId);
        listPreference.setEntryValues(citiesResId);
        ((EditTextPreference) findPreference("KEY_HOTLINE" + this.userIndex)).setSummary(this.cfg.getHotline(this.userIndex));
        ((EditTextPreference) findPreference("KEY_NAME" + this.userIndex)).setSummary(this.cfg.getUserName(this.userIndex));
        ((EditTextPreference) findPreference("KEY_ID" + this.userIndex)).setSummary(this.cfg.getUserId(this.userIndex));
        EditTextPreference editTextPreference = (EditTextPreference) findPreference("KEY_CONTENT" + this.userIndex);
        if (editTextPreference != null) {
            SharedPreferences sharedPreferences = this.sharedPrefs;
            editTextPreference.setSummary(sharedPreferences.getString("KEY_CONTENT" + this.userIndex, getString(R.string.default_content)));
            ((PreferenceCategory) findPreference("KEY_OTHER")).removePreference(editTextPreference);
        }
        ((ListPreference) findPreference("KEY_COLOR" + this.userIndex)).setSummary(this.cfg.getColorName(this.userIndex));
        getPreferenceScreen().getSharedPreferences().registerOnSharedPreferenceChangeListener(this);
    }

    /* access modifiers changed from: protected */
    public void onPause() {
        getPreferenceScreen().getSharedPreferences().unregisterOnSharedPreferenceChangeListener(this);
        super.onPause();
    }

    public void onSharedPreferenceChanged(SharedPreferences sharedPreferences, String str) {
        Preference findPreference = findPreference(str);
        if (findPreference instanceof EditTextPreference) {
            findPreference.setSummary(((EditTextPreference) findPreference).getText());
        } else if (findPreference instanceof ListPreference) {
            ListPreference listPreference = (ListPreference) findPreference;
            listPreference.setSummary(listPreference.getEntry());
            if (str.equals("KEY_PROVINCE" + this.userIndex)) {
                this.cfg.resetCity(this.userIndex);
                ListPreference listPreference2 = (ListPreference) findPreference("KEY_CITY" + this.userIndex);
                int citiesResId = this.cfg.getCitiesResId(this.userIndex);
                listPreference2.setEntries(citiesResId);
                listPreference2.setEntryValues(citiesResId);
                listPreference2.setValueIndex(0);
                listPreference2.setSummary(this.cfg.getCity(this.userIndex));
                this.cfg.resetHotline(this.userIndex);
                EditTextPreference editTextPreference = (EditTextPreference) findPreference("KEY_HOTLINE" + this.userIndex);
                String hotline = this.cfg.getHotline(this.userIndex);
                editTextPreference.setText(hotline);
                editTextPreference.setSummary(hotline);
                return;
            }
            if (str.equals("KEY_CITY" + this.userIndex)) {
                this.cfg.resetHotline(this.userIndex);
                EditTextPreference editTextPreference2 = (EditTextPreference) findPreference("KEY_HOTLINE" + this.userIndex);
                String hotline2 = this.cfg.getHotline(this.userIndex);
                editTextPreference2.setText(hotline2);
                editTextPreference2.setSummary(hotline2);
            }
        }
    }
}
