package com.google.zxing.aztec.encoder;

import com.google.zxing.common.BitArray;
import java.lang.reflect.Array;
import java.util.Arrays;
import java.util.Collection;
import java.util.Collections;
import java.util.Comparator;
import java.util.Iterator;
import java.util.LinkedList;

public final class HighLevelEncoder {
    private static final int[][] CHAR_MAP = ((int[][]) Array.newInstance(int.class, 5, 256));
    static final int[][] LATCH_TABLE = {new int[]{0, 327708, 327710, 327709, 656318}, new int[]{590318, 0, 327710, 327709, 656318}, new int[]{262158, 590300, 0, 590301, 932798}, new int[]{327709, 327708, 656318, 0, 327710}, new int[]{327711, 656380, 656382, 656381, 0}};
    static final int MODE_DIGIT = 2;
    static final int MODE_LOWER = 1;
    static final int MODE_MIXED = 3;
    static final String[] MODE_NAMES = {"UPPER", "LOWER", "DIGIT", "MIXED", "PUNCT"};
    static final int MODE_PUNCT = 4;
    static final int MODE_UPPER = 0;
    static final int[][] SHIFT_TABLE = ((int[][]) Array.newInstance(int.class, 6, 6));
    private final byte[] text;

    static {
        CHAR_MAP[0][32] = MODE_LOWER;
        for (int i = 65; i <= 90; i += MODE_LOWER) {
            CHAR_MAP[0][i] = (i - 65) + MODE_DIGIT;
        }
        CHAR_MAP[MODE_LOWER][32] = MODE_LOWER;
        for (int i2 = 97; i2 <= 122; i2 += MODE_LOWER) {
            CHAR_MAP[MODE_LOWER][i2] = (i2 - 97) + MODE_DIGIT;
        }
        CHAR_MAP[MODE_DIGIT][32] = MODE_LOWER;
        for (int i3 = 48; i3 <= 57; i3 += MODE_LOWER) {
            CHAR_MAP[MODE_DIGIT][i3] = (i3 - 48) + MODE_DIGIT;
        }
        int[][] iArr = CHAR_MAP;
        iArr[MODE_DIGIT][44] = 12;
        iArr[MODE_DIGIT][46] = 13;
        int[] iArr2 = {0, 32, MODE_LOWER, MODE_DIGIT, 3, MODE_PUNCT, 5, 6, 7, 8, 9, 10, 11, 12, 13, 27, 28, 29, 30, 31, 64, 92, 94, 95, 96, 124, 126, 127};
        for (int i4 = 0; i4 < iArr2.length; i4 += MODE_LOWER) {
            CHAR_MAP[3][iArr2[i4]] = i4;
        }
        int[] iArr3 = {0, 13, 0, 0, 0, 0, 33, 39, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 58, 59, 60, 61, 62, 63, 91, 93, 123, 125};
        for (int i5 = 0; i5 < iArr3.length; i5 += MODE_LOWER) {
            if (iArr3[i5] > 0) {
                CHAR_MAP[MODE_PUNCT][iArr3[i5]] = i5;
            }
        }
        int[][] iArr4 = SHIFT_TABLE;
        int length = iArr4.length;
        for (int i6 = 0; i6 < length; i6 += MODE_LOWER) {
            Arrays.fill(iArr4[i6], -1);
        }
        int[][] iArr5 = SHIFT_TABLE;
        iArr5[0][MODE_PUNCT] = 0;
        iArr5[MODE_LOWER][MODE_PUNCT] = 0;
        iArr5[MODE_LOWER][0] = 28;
        iArr5[3][MODE_PUNCT] = 0;
        iArr5[MODE_DIGIT][MODE_PUNCT] = 0;
        iArr5[MODE_DIGIT][0] = 15;
    }

    public HighLevelEncoder(byte[] bArr) {
        this.text = bArr;
    }

    /* JADX WARNING: Removed duplicated region for block: B:26:0x0042  */
    /* JADX WARNING: Removed duplicated region for block: B:27:0x0049  */
    public BitArray encode() {
        int i;
        Collection<State> collection;
        Collection<State> singletonList = Collections.singletonList(State.INITIAL_STATE);
        int i2 = 0;
        while (true) {
            byte[] bArr = this.text;
            if (i2 >= bArr.length) {
                return ((State) Collections.min(singletonList, new Comparator<State>() {
                    /* class com.google.zxing.aztec.encoder.HighLevelEncoder.AnonymousClass1 */

                    public int compare(State state, State state2) {
                        return state.getBitCount() - state2.getBitCount();
                    }
                })).toBitArray(this.text);
            }
            int i3 = i2 + MODE_LOWER;
            byte b = i3 < bArr.length ? bArr[i3] : 0;
            byte b2 = this.text[i2];
            if (b2 != 13) {
                if (b2 != 44) {
                    if (b2 != 46) {
                        if (b2 == 58 && b == 32) {
                            i = 5;
                            if (i > 0) {
                                collection = updateStateListForPair(singletonList, i2, i);
                                i2 = i3;
                            } else {
                                collection = updateStateListForChar(singletonList, i2);
                            }
                            i2 += MODE_LOWER;
                            singletonList = collection;
                        }
                    } else if (b == 32) {
                        i = 3;
                        if (i > 0) {
                        }
                        i2 += MODE_LOWER;
                        singletonList = collection;
                    }
                } else if (b == 32) {
                    i = MODE_PUNCT;
                    if (i > 0) {
                    }
                    i2 += MODE_LOWER;
                    singletonList = collection;
                }
            } else if (b == 10) {
                i = MODE_DIGIT;
                if (i > 0) {
                }
                i2 += MODE_LOWER;
                singletonList = collection;
            }
            i = 0;
            if (i > 0) {
            }
            i2 += MODE_LOWER;
            singletonList = collection;
        }
    }

    private Collection<State> updateStateListForChar(Iterable<State> iterable, int i) {
        LinkedList linkedList = new LinkedList();
        for (State state : iterable) {
            updateStateForChar(state, i, linkedList);
        }
        return simplifyStates(linkedList);
    }

    private void updateStateForChar(State state, int i, Collection<State> collection) {
        char c = (char) (this.text[i] & 255);
        boolean z = CHAR_MAP[state.getMode()][c] > 0;
        State state2 = null;
        for (int i2 = 0; i2 <= MODE_PUNCT; i2 += MODE_LOWER) {
            int i3 = CHAR_MAP[i2][c];
            if (i3 > 0) {
                if (state2 == null) {
                    state2 = state.endBinaryShift(i);
                }
                if (!z || i2 == state.getMode() || i2 == MODE_DIGIT) {
                    collection.add(state2.latchAndAppend(i2, i3));
                }
                if (!z && SHIFT_TABLE[state.getMode()][i2] >= 0) {
                    collection.add(state2.shiftAndAppend(i2, i3));
                }
            }
        }
        if (state.getBinaryShiftByteCount() > 0 || CHAR_MAP[state.getMode()][c] == 0) {
            collection.add(state.addBinaryShiftChar(i));
        }
    }

    private static Collection<State> updateStateListForPair(Iterable<State> iterable, int i, int i2) {
        LinkedList linkedList = new LinkedList();
        for (State state : iterable) {
            updateStateForPair(state, i, i2, linkedList);
        }
        return simplifyStates(linkedList);
    }

    private static void updateStateForPair(State state, int i, int i2, Collection<State> collection) {
        State endBinaryShift = state.endBinaryShift(i);
        collection.add(endBinaryShift.latchAndAppend(MODE_PUNCT, i2));
        if (state.getMode() != MODE_PUNCT) {
            collection.add(endBinaryShift.shiftAndAppend(MODE_PUNCT, i2));
        }
        if (i2 == 3 || i2 == MODE_PUNCT) {
            collection.add(endBinaryShift.latchAndAppend(MODE_DIGIT, 16 - i2).latchAndAppend(MODE_DIGIT, MODE_LOWER));
        }
        if (state.getBinaryShiftByteCount() > 0) {
            collection.add(state.addBinaryShiftChar(i).addBinaryShiftChar(i + MODE_LOWER));
        }
    }

    private static Collection<State> simplifyStates(Iterable<State> iterable) {
        LinkedList linkedList = new LinkedList();
        for (State state : iterable) {
            boolean z = true;
            Iterator it = linkedList.iterator();
            while (true) {
                if (!it.hasNext()) {
                    break;
                }
                State state2 = (State) it.next();
                if (state2.isBetterThanOrEqualTo(state)) {
                    z = false;
                    break;
                } else if (state.isBetterThanOrEqualTo(state2)) {
                    it.remove();
                }
            }
            if (z) {
                linkedList.add(state);
            }
        }
        return linkedList;
    }
}
