package com.google.zxing.pdf417.decoder;

import com.google.zxing.FormatException;
import com.google.zxing.common.CharacterSetECI;
import com.google.zxing.common.DecoderResult;
import com.google.zxing.pdf417.PDF417ResultMetadata;
import java.io.ByteArrayOutputStream;
import java.math.BigInteger;
import java.nio.charset.Charset;
import java.nio.charset.StandardCharsets;
import java.util.Arrays;

/* access modifiers changed from: package-private */
public final class DecodedBitStreamParser {
    private static final int AL = 28;
    private static final int AS = 27;
    private static final int BEGIN_MACRO_PDF417_CONTROL_BLOCK = 928;
    private static final int BEGIN_MACRO_PDF417_OPTIONAL_FIELD = 923;
    private static final int BYTE_COMPACTION_MODE_LATCH = 901;
    private static final int BYTE_COMPACTION_MODE_LATCH_6 = 924;
    private static final int ECI_CHARSET = 927;
    private static final int ECI_GENERAL_PURPOSE = 926;
    private static final int ECI_USER_DEFINED = 925;
    private static final BigInteger[] EXP900 = new BigInteger[16];
    private static final int LL = 27;
    private static final int MACRO_PDF417_OPTIONAL_FIELD_ADDRESSEE = 4;
    private static final int MACRO_PDF417_OPTIONAL_FIELD_CHECKSUM = 6;
    private static final int MACRO_PDF417_OPTIONAL_FIELD_FILE_NAME = 0;
    private static final int MACRO_PDF417_OPTIONAL_FIELD_FILE_SIZE = 5;
    private static final int MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT = 1;
    private static final int MACRO_PDF417_OPTIONAL_FIELD_SENDER = 3;
    private static final int MACRO_PDF417_OPTIONAL_FIELD_TIME_STAMP = 2;
    private static final int MACRO_PDF417_TERMINATOR = 922;
    private static final int MAX_NUMERIC_CODEWORDS = 15;
    private static final char[] MIXED_CHARS = "0123456789&\r\t,:#-.$/+%*=^".toCharArray();
    private static final int ML = 28;
    private static final int MODE_SHIFT_TO_BYTE_COMPACTION_MODE = 913;
    private static final int NUMBER_OF_SEQUENCE_CODEWORDS = 2;
    private static final int NUMERIC_COMPACTION_MODE_LATCH = 902;
    private static final int PAL = 29;
    private static final int PL = 25;
    private static final int PS = 29;
    private static final char[] PUNCT_CHARS = ";<>@[\\]_`~!\r\t,:\n-.$/\"|*()?{}'".toCharArray();
    private static final int TEXT_COMPACTION_MODE_LATCH = 900;

    /* JADX INFO: Failed to restore enum class, 'enum' modifier removed */
    /* access modifiers changed from: private */
    public static final class Mode extends Enum<Mode> {
        private static final /* synthetic */ Mode[] $VALUES;
        public static final Mode ALPHA = new Mode("ALPHA", 0);
        public static final Mode ALPHA_SHIFT = new Mode("ALPHA_SHIFT", DecodedBitStreamParser.MACRO_PDF417_OPTIONAL_FIELD_ADDRESSEE);
        public static final Mode LOWER = new Mode("LOWER", DecodedBitStreamParser.MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT);
        public static final Mode MIXED = new Mode("MIXED", 2);
        public static final Mode PUNCT = new Mode("PUNCT", 3);
        public static final Mode PUNCT_SHIFT = new Mode("PUNCT_SHIFT", DecodedBitStreamParser.MACRO_PDF417_OPTIONAL_FIELD_FILE_SIZE);

        private Mode(String str, int i) {
        }

        public static Mode valueOf(String str) {
            return (Mode) Enum.valueOf(Mode.class, str);
        }

        public static Mode[] values() {
            return (Mode[]) $VALUES.clone();
        }

        static {
            Mode[] modeArr = new Mode[DecodedBitStreamParser.MACRO_PDF417_OPTIONAL_FIELD_CHECKSUM];
            modeArr[0] = ALPHA;
            modeArr[DecodedBitStreamParser.MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT] = LOWER;
            modeArr[2] = MIXED;
            modeArr[3] = PUNCT;
            modeArr[DecodedBitStreamParser.MACRO_PDF417_OPTIONAL_FIELD_ADDRESSEE] = ALPHA_SHIFT;
            modeArr[DecodedBitStreamParser.MACRO_PDF417_OPTIONAL_FIELD_FILE_SIZE] = PUNCT_SHIFT;
            $VALUES = modeArr;
        }
    }

    static {
        EXP900[0] = BigInteger.ONE;
        BigInteger valueOf = BigInteger.valueOf(900);
        EXP900[MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT] = valueOf;
        int i = 2;
        while (true) {
            BigInteger[] bigIntegerArr = EXP900;
            if (i < bigIntegerArr.length) {
                bigIntegerArr[i] = bigIntegerArr[i - 1].multiply(valueOf);
                i += MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT;
            } else {
                return;
            }
        }
    }

    private DecodedBitStreamParser() {
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    /* JADX WARNING: Removed duplicated region for block: B:15:0x0051  */
    static DecoderResult decode(int[] iArr, String str) throws FormatException {
        int i;
        int i2 = 2;
        StringBuilder sb = new StringBuilder(iArr.length * 2);
        Charset charset = StandardCharsets.ISO_8859_1;
        int i3 = iArr[MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT];
        PDF417ResultMetadata pDF417ResultMetadata = new PDF417ResultMetadata();
        while (i2 < iArr[0]) {
            if (i3 != MODE_SHIFT_TO_BYTE_COMPACTION_MODE) {
                switch (i3) {
                    case TEXT_COMPACTION_MODE_LATCH /*{ENCODED_INT: 900}*/:
                        i = textCompaction(iArr, i2, sb);
                        break;
                    case BYTE_COMPACTION_MODE_LATCH /*{ENCODED_INT: 901}*/:
                        i = byteCompaction(i3, iArr, charset, i2, sb);
                        break;
                    case NUMERIC_COMPACTION_MODE_LATCH /*{ENCODED_INT: 902}*/:
                        i = numericCompaction(iArr, i2, sb);
                        break;
                    default:
                        switch (i3) {
                            case MACRO_PDF417_TERMINATOR /*{ENCODED_INT: 922}*/:
                            case BEGIN_MACRO_PDF417_OPTIONAL_FIELD /*{ENCODED_INT: 923}*/:
                                throw FormatException.getFormatInstance();
                            case BYTE_COMPACTION_MODE_LATCH_6 /*{ENCODED_INT: 924}*/:
                                break;
                            case ECI_USER_DEFINED /*{ENCODED_INT: 925}*/:
                                i = i2 + MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT;
                                break;
                            case ECI_GENERAL_PURPOSE /*{ENCODED_INT: 926}*/:
                                i = i2 + 2;
                                break;
                            case ECI_CHARSET /*{ENCODED_INT: 927}*/:
                                int i4 = i2 + MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT;
                                Charset forName = Charset.forName(CharacterSetECI.getCharacterSetECIByValue(iArr[i2]).name());
                                i = i4;
                                charset = forName;
                                break;
                            case 928:
                                i = decodeMacroBlock(iArr, i2, pDF417ResultMetadata);
                                break;
                            default:
                                i = textCompaction(iArr, i2 - 1, sb);
                                break;
                        }
                }
            } else {
                int i5 = i2 + MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT;
                sb.append((char) iArr[i2]);
                i = i5;
            }
            if (i < iArr.length) {
                int i6 = i + MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT;
                i3 = iArr[i];
                i2 = i6;
            } else {
                throw FormatException.getFormatInstance();
            }
        }
        if (sb.length() != 0) {
            DecoderResult decoderResult = new DecoderResult(null, sb.toString(), null, str);
            decoderResult.setOther(pDF417ResultMetadata);
            return decoderResult;
        }
        throw FormatException.getFormatInstance();
    }

    static int decodeMacroBlock(int[] iArr, int i, PDF417ResultMetadata pDF417ResultMetadata) throws FormatException {
        if (i + 2 <= iArr[0]) {
            int[] iArr2 = new int[2];
            int i2 = i;
            int i3 = 0;
            while (i3 < 2) {
                iArr2[i3] = iArr[i2];
                i3 += MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT;
                i2 += MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT;
            }
            pDF417ResultMetadata.setSegmentIndex(Integer.parseInt(decodeBase900toBase10(iArr2, 2)));
            StringBuilder sb = new StringBuilder();
            int textCompaction = textCompaction(iArr, i2, sb);
            pDF417ResultMetadata.setFileId(sb.toString());
            int i4 = iArr[textCompaction] == BEGIN_MACRO_PDF417_OPTIONAL_FIELD ? textCompaction + MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT : -1;
            while (textCompaction < iArr[0]) {
                int i5 = iArr[textCompaction];
                if (i5 == MACRO_PDF417_TERMINATOR) {
                    textCompaction += MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT;
                    pDF417ResultMetadata.setLastSegment(true);
                } else if (i5 == BEGIN_MACRO_PDF417_OPTIONAL_FIELD) {
                    int i6 = textCompaction + MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT;
                    switch (iArr[i6]) {
                        case 0:
                            StringBuilder sb2 = new StringBuilder();
                            textCompaction = textCompaction(iArr, i6 + MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT, sb2);
                            pDF417ResultMetadata.setFileName(sb2.toString());
                            continue;
                        case MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT /*{ENCODED_INT: 1}*/:
                            StringBuilder sb3 = new StringBuilder();
                            textCompaction = numericCompaction(iArr, i6 + MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT, sb3);
                            pDF417ResultMetadata.setSegmentCount(Integer.parseInt(sb3.toString()));
                            continue;
                        case 2:
                            StringBuilder sb4 = new StringBuilder();
                            textCompaction = numericCompaction(iArr, i6 + MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT, sb4);
                            pDF417ResultMetadata.setTimestamp(Long.parseLong(sb4.toString()));
                            continue;
                        case 3:
                            StringBuilder sb5 = new StringBuilder();
                            textCompaction = textCompaction(iArr, i6 + MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT, sb5);
                            pDF417ResultMetadata.setSender(sb5.toString());
                            continue;
                        case MACRO_PDF417_OPTIONAL_FIELD_ADDRESSEE /*{ENCODED_INT: 4}*/:
                            StringBuilder sb6 = new StringBuilder();
                            textCompaction = textCompaction(iArr, i6 + MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT, sb6);
                            pDF417ResultMetadata.setAddressee(sb6.toString());
                            continue;
                        case MACRO_PDF417_OPTIONAL_FIELD_FILE_SIZE /*{ENCODED_INT: 5}*/:
                            StringBuilder sb7 = new StringBuilder();
                            textCompaction = numericCompaction(iArr, i6 + MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT, sb7);
                            pDF417ResultMetadata.setFileSize(Long.parseLong(sb7.toString()));
                            continue;
                        case MACRO_PDF417_OPTIONAL_FIELD_CHECKSUM /*{ENCODED_INT: 6}*/:
                            StringBuilder sb8 = new StringBuilder();
                            textCompaction = numericCompaction(iArr, i6 + MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT, sb8);
                            pDF417ResultMetadata.setChecksum(Integer.parseInt(sb8.toString()));
                            continue;
                        default:
                            throw FormatException.getFormatInstance();
                    }
                } else {
                    throw FormatException.getFormatInstance();
                }
            }
            if (i4 != -1) {
                int i7 = textCompaction - i4;
                if (pDF417ResultMetadata.isLastSegment()) {
                    i7--;
                }
                pDF417ResultMetadata.setOptionalData(Arrays.copyOfRange(iArr, i4, i7 + i4));
            }
            return textCompaction;
        }
        throw FormatException.getFormatInstance();
    }

    private static int textCompaction(int[] iArr, int i, StringBuilder sb) {
        int[] iArr2 = new int[((iArr[0] - i) * 2)];
        int[] iArr3 = new int[((iArr[0] - i) * 2)];
        boolean z = false;
        int i2 = 0;
        while (i < iArr[0] && !z) {
            int i3 = i + MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT;
            int i4 = iArr[i];
            if (i4 < TEXT_COMPACTION_MODE_LATCH) {
                iArr2[i2] = i4 / 30;
                iArr2[i2 + MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT] = i4 % 30;
                i2 += 2;
            } else if (i4 != MODE_SHIFT_TO_BYTE_COMPACTION_MODE) {
                if (i4 != 928) {
                    switch (i4) {
                        case TEXT_COMPACTION_MODE_LATCH /*{ENCODED_INT: 900}*/:
                            int i5 = i2 + MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT;
                            iArr2[i2] = TEXT_COMPACTION_MODE_LATCH;
                            i2 = i5;
                            break;
                        default:
                            switch (i4) {
                            }
                        case BYTE_COMPACTION_MODE_LATCH /*{ENCODED_INT: 901}*/:
                        case NUMERIC_COMPACTION_MODE_LATCH /*{ENCODED_INT: 902}*/:
                            i3--;
                            z = MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT;
                            break;
                    }
                }
                i3--;
                z = MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT;
            } else {
                iArr2[i2] = MODE_SHIFT_TO_BYTE_COMPACTION_MODE;
                i = i3 + MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT;
                iArr3[i2] = iArr[i3];
                i2 += MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT;
            }
            i = i3;
        }
        decodeTextCompaction(iArr2, iArr3, i2, sb);
        return i;
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    private static void decodeTextCompaction(int[] iArr, int[] iArr2, int i, StringBuilder sb) {
        char c;
        Mode mode;
        int i2;
        char c2;
        Mode mode2 = Mode.ALPHA;
        Mode mode3 = Mode.ALPHA;
        Mode mode4 = mode2;
        for (int i3 = 0; i3 < i; i3 += MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT) {
            int i4 = iArr[i3];
            char c3 = ' ';
            switch (AnonymousClass1.$SwitchMap$com$google$zxing$pdf417$decoder$DecodedBitStreamParser$Mode[mode4.ordinal()]) {
                case MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT /*{ENCODED_INT: 1}*/:
                    if (i4 < 26) {
                        i2 = i4 + 65;
                        c = (char) i2;
                        break;
                    } else {
                        if (i4 == TEXT_COMPACTION_MODE_LATCH) {
                            mode4 = Mode.ALPHA;
                        } else if (i4 != MODE_SHIFT_TO_BYTE_COMPACTION_MODE) {
                            switch (i4) {
                                case 27:
                                    mode4 = Mode.LOWER;
                                    break;
                                case 28:
                                    mode4 = Mode.MIXED;
                                    break;
                                case 29:
                                    mode = Mode.PUNCT_SHIFT;
                                    c3 = 0;
                                    mode3 = mode4;
                                    mode4 = mode;
                                    break;
                            }
                            c = c3;
                            break;
                        } else {
                            sb.append((char) iArr2[i3]);
                        }
                        c3 = 0;
                        c = c3;
                    }
                case 2:
                    if (i4 < 26) {
                        i2 = i4 + 97;
                        c = (char) i2;
                        break;
                    } else {
                        if (i4 == TEXT_COMPACTION_MODE_LATCH) {
                            mode4 = Mode.ALPHA;
                        } else if (i4 != MODE_SHIFT_TO_BYTE_COMPACTION_MODE) {
                            switch (i4) {
                                case 27:
                                    mode = Mode.ALPHA_SHIFT;
                                    c3 = 0;
                                    mode3 = mode4;
                                    mode4 = mode;
                                    break;
                                case 28:
                                    mode4 = Mode.MIXED;
                                    break;
                                case 29:
                                    mode = Mode.PUNCT_SHIFT;
                                    c3 = 0;
                                    mode3 = mode4;
                                    mode4 = mode;
                                    break;
                            }
                            c = c3;
                            break;
                        } else {
                            sb.append((char) iArr2[i3]);
                        }
                        c3 = 0;
                        c = c3;
                    }
                case 3:
                    if (i4 < PL) {
                        c = MIXED_CHARS[i4];
                        break;
                    } else {
                        if (i4 != TEXT_COMPACTION_MODE_LATCH) {
                            if (i4 != MODE_SHIFT_TO_BYTE_COMPACTION_MODE) {
                                switch (i4) {
                                    case PL /*{ENCODED_INT: 25}*/:
                                        mode4 = Mode.PUNCT;
                                        break;
                                    case 27:
                                        mode4 = Mode.LOWER;
                                        break;
                                    case 29:
                                        mode = Mode.PUNCT_SHIFT;
                                        c3 = 0;
                                        mode3 = mode4;
                                        mode4 = mode;
                                        break;
                                }
                                c = c3;
                                break;
                            } else {
                                sb.append((char) iArr2[i3]);
                            }
                            c3 = 0;
                            c = c3;
                        }
                        mode4 = Mode.ALPHA;
                        c3 = 0;
                        c = c3;
                    }
                case MACRO_PDF417_OPTIONAL_FIELD_ADDRESSEE /*{ENCODED_INT: 4}*/:
                    if (i4 < 29) {
                        c = PUNCT_CHARS[i4];
                        break;
                    } else if (i4 == 29 || i4 == TEXT_COMPACTION_MODE_LATCH) {
                        mode4 = Mode.ALPHA;
                        c = 0;
                        break;
                    } else {
                        if (i4 == MODE_SHIFT_TO_BYTE_COMPACTION_MODE) {
                            sb.append((char) iArr2[i3]);
                        }
                        c = 0;
                    }
                case MACRO_PDF417_OPTIONAL_FIELD_FILE_SIZE /*{ENCODED_INT: 5}*/:
                    if (i4 < 26) {
                        c2 = (char) (i4 + 65);
                        c = c2;
                        mode4 = mode3;
                        break;
                    } else {
                        if (i4 != 26) {
                            if (i4 == TEXT_COMPACTION_MODE_LATCH) {
                                mode4 = Mode.ALPHA;
                                c3 = 0;
                                c = c3;
                                break;
                            } else {
                                c3 = 0;
                            }
                        }
                        mode4 = mode3;
                        c = c3;
                    }
                case MACRO_PDF417_OPTIONAL_FIELD_CHECKSUM /*{ENCODED_INT: 6}*/:
                    if (i4 < 29) {
                        c2 = PUNCT_CHARS[i4];
                        c = c2;
                        mode4 = mode3;
                        break;
                    } else if (i4 == 29 || i4 == TEXT_COMPACTION_MODE_LATCH) {
                        mode4 = Mode.ALPHA;
                        c = 0;
                        break;
                    } else {
                        if (i4 == MODE_SHIFT_TO_BYTE_COMPACTION_MODE) {
                            sb.append((char) iArr2[i3]);
                        }
                        c = 0;
                        mode4 = mode3;
                    }
                default:
                    c = 0;
                    break;
            }
            if (c != 0) {
                sb.append(c);
            }
        }
    }

    /* access modifiers changed from: package-private */
    /* renamed from: com.google.zxing.pdf417.decoder.DecodedBitStreamParser$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$com$google$zxing$pdf417$decoder$DecodedBitStreamParser$Mode = new int[Mode.values().length];

        /* JADX WARNING: Can't wrap try/catch for region: R(12:0|1|2|3|4|5|6|7|8|9|10|(3:11|12|14)) */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:11:0x0040 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x0014 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:5:0x001f */
        /* JADX WARNING: Missing exception handler attribute for start block: B:7:0x002a */
        /* JADX WARNING: Missing exception handler attribute for start block: B:9:0x0035 */
        static {
            $SwitchMap$com$google$zxing$pdf417$decoder$DecodedBitStreamParser$Mode[Mode.ALPHA.ordinal()] = DecodedBitStreamParser.MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT;
            $SwitchMap$com$google$zxing$pdf417$decoder$DecodedBitStreamParser$Mode[Mode.LOWER.ordinal()] = 2;
            $SwitchMap$com$google$zxing$pdf417$decoder$DecodedBitStreamParser$Mode[Mode.MIXED.ordinal()] = 3;
            $SwitchMap$com$google$zxing$pdf417$decoder$DecodedBitStreamParser$Mode[Mode.PUNCT.ordinal()] = DecodedBitStreamParser.MACRO_PDF417_OPTIONAL_FIELD_ADDRESSEE;
            $SwitchMap$com$google$zxing$pdf417$decoder$DecodedBitStreamParser$Mode[Mode.ALPHA_SHIFT.ordinal()] = DecodedBitStreamParser.MACRO_PDF417_OPTIONAL_FIELD_FILE_SIZE;
            try {
                $SwitchMap$com$google$zxing$pdf417$decoder$DecodedBitStreamParser$Mode[Mode.PUNCT_SHIFT.ordinal()] = DecodedBitStreamParser.MACRO_PDF417_OPTIONAL_FIELD_CHECKSUM;
            } catch (NoSuchFieldError unused) {
            }
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:20:0x0045 A[ADDED_TO_REGION] */
    /* JADX WARNING: Removed duplicated region for block: B:56:0x0021 A[ADDED_TO_REGION, SYNTHETIC] */
    private static int byteCompaction(int i, int[] iArr, Charset charset, int i2, StringBuilder sb) {
        int i3;
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        long j = 900;
        int i4 = MACRO_PDF417_OPTIONAL_FIELD_CHECKSUM;
        if (i == BYTE_COMPACTION_MODE_LATCH) {
            int[] iArr2 = new int[MACRO_PDF417_OPTIONAL_FIELD_CHECKSUM];
            int i5 = i2 + MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT;
            int i6 = iArr[i2];
            boolean z = false;
            int i7 = 0;
            while (true) {
                long j2 = 0;
                while (i5 < iArr[0] && !z) {
                    int i8 = i7 + MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT;
                    iArr2[i7] = i6;
                    j2 = (j2 * j) + ((long) i6);
                    int i9 = i5 + MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT;
                    i6 = iArr[i5];
                    if (i6 != 928) {
                        switch (i6) {
                            case TEXT_COMPACTION_MODE_LATCH /*{ENCODED_INT: 900}*/:
                            case BYTE_COMPACTION_MODE_LATCH /*{ENCODED_INT: 901}*/:
                            case NUMERIC_COMPACTION_MODE_LATCH /*{ENCODED_INT: 902}*/:
                                break;
                            default:
                                switch (i6) {
                                    case MACRO_PDF417_TERMINATOR /*{ENCODED_INT: 922}*/:
                                    case BEGIN_MACRO_PDF417_OPTIONAL_FIELD /*{ENCODED_INT: 923}*/:
                                    case BYTE_COMPACTION_MODE_LATCH_6 /*{ENCODED_INT: 924}*/:
                                        break;
                                    default:
                                        if (i8 % MACRO_PDF417_OPTIONAL_FIELD_FILE_SIZE != 0 || i8 <= 0) {
                                            z = z;
                                            i5 = i9;
                                            i7 = i8;
                                            j = 900;
                                            i4 = MACRO_PDF417_OPTIONAL_FIELD_CHECKSUM;
                                        } else {
                                            int i10 = 0;
                                            while (i10 < i4) {
                                                byteArrayOutputStream.write((byte) ((int) (j2 >> ((5 - i10) * 8))));
                                                i10 += MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT;
                                                i4 = MACRO_PDF417_OPTIONAL_FIELD_CHECKSUM;
                                                z = z;
                                            }
                                            i5 = i9;
                                            i7 = 0;
                                            j = 900;
                                        }
                                }
                                break;
                        }
                    }
                    i5 = i9 - 1;
                    i7 = i8;
                    j = 900;
                    i4 = MACRO_PDF417_OPTIONAL_FIELD_CHECKSUM;
                    z = true;
                }
            }
            if (i5 == iArr[0] && i6 < TEXT_COMPACTION_MODE_LATCH) {
                int i11 = i7 + MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT;
                iArr2[i7] = i6;
                i7 = i11;
            }
            for (int i12 = 0; i12 < i7; i12 += MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT) {
                byteArrayOutputStream.write((byte) iArr2[i12]);
            }
            i3 = i5;
        } else if (i != BYTE_COMPACTION_MODE_LATCH_6) {
            i3 = i2;
        } else {
            i3 = i2;
            boolean z2 = false;
            int i13 = 0;
            while (true) {
                long j3 = 0;
                while (i3 < iArr[0] && !z2) {
                    int i14 = i3 + MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT;
                    int i15 = iArr[i3];
                    if (i15 < TEXT_COMPACTION_MODE_LATCH) {
                        i13 += MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT;
                        j3 = (j3 * 900) + ((long) i15);
                    } else {
                        if (i15 != 928) {
                            switch (i15) {
                                default:
                                    switch (i15) {
                                    }
                                case TEXT_COMPACTION_MODE_LATCH /*{ENCODED_INT: 900}*/:
                                case BYTE_COMPACTION_MODE_LATCH /*{ENCODED_INT: 901}*/:
                                case NUMERIC_COMPACTION_MODE_LATCH /*{ENCODED_INT: 902}*/:
                                    i3 = i14 - 1;
                                    z2 = true;
                                    break;
                            }
                            if (i13 % MACRO_PDF417_OPTIONAL_FIELD_FILE_SIZE == 0 && i13 > 0) {
                                for (int i16 = 0; i16 < MACRO_PDF417_OPTIONAL_FIELD_CHECKSUM; i16 += MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT) {
                                    byteArrayOutputStream.write((byte) ((int) (j3 >> ((5 - i16) * 8))));
                                }
                                i13 = 0;
                            }
                        }
                        i3 = i14 - 1;
                        z2 = true;
                        if (i13 % MACRO_PDF417_OPTIONAL_FIELD_FILE_SIZE == 0) {
                        }
                    }
                    i3 = i14;
                    if (i13 % MACRO_PDF417_OPTIONAL_FIELD_FILE_SIZE == 0) {
                    }
                }
            }
        }
        sb.append(new String(byteArrayOutputStream.toByteArray(), charset));
        return i3;
    }

    private static int numericCompaction(int[] iArr, int i, StringBuilder sb) throws FormatException {
        int[] iArr2 = new int[MAX_NUMERIC_CODEWORDS];
        boolean z = false;
        int i2 = 0;
        while (i < iArr[0] && !z) {
            int i3 = i + MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT;
            int i4 = iArr[i];
            if (i3 == iArr[0]) {
                z = MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT;
            }
            if (i4 < TEXT_COMPACTION_MODE_LATCH) {
                iArr2[i2] = i4;
                i2 += MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT;
            } else {
                if (!(i4 == TEXT_COMPACTION_MODE_LATCH || i4 == BYTE_COMPACTION_MODE_LATCH || i4 == 928)) {
                    switch (i4) {
                    }
                }
                i3--;
                z = MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT;
            }
            if ((i2 % MAX_NUMERIC_CODEWORDS == 0 || i4 == NUMERIC_COMPACTION_MODE_LATCH || z) && i2 > 0) {
                sb.append(decodeBase900toBase10(iArr2, i2));
                i2 = 0;
            }
            i = i3;
        }
        return i;
    }

    private static String decodeBase900toBase10(int[] iArr, int i) throws FormatException {
        BigInteger bigInteger = BigInteger.ZERO;
        for (int i2 = 0; i2 < i; i2 += MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT) {
            bigInteger = bigInteger.add(EXP900[(i - i2) - MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT].multiply(BigInteger.valueOf((long) iArr[i2])));
        }
        String bigInteger2 = bigInteger.toString();
        if (bigInteger2.charAt(0) == '1') {
            return bigInteger2.substring(MACRO_PDF417_OPTIONAL_FIELD_SEGMENT_COUNT);
        }
        throw FormatException.getFormatInstance();
    }
}
